class EpuckCommSubscriberTopic{
  
private :

  std::string IP;
  
  int worksiteX;
  int worksiteY;
  int worksiteId;
  int recruiterId;

  
  std::string SubscriberTopicName;
  
public:
  
  ros::Subscriber SubscriberTopicNode;

  EpuckCommSubscriberTopic(){};
  ~EpuckCommSubscriberTopic(){};
  
  void UpdatePositionCallback(const cpp_observer::ViconPosition::ConstPtr& msg);

  int GetWorksiteX();
  int GetWorksiteY();
  int GetWorksiteId();
  int GetRecruiterId();


  void SetTopicName(std::string TopicName);
  std::string* GetTopicName();
  void SetIP(std::string IP);
  std::string* GetIP();

};
